@@ -2,7 +2,7 @@ package Spreadsheet::XLSX::Reader::LibXML::Types;
 BEGIN {
   $Spreadsheet::XLSX::Reader::LibXML::Types::AUTHORITY = 'cpan:JANDREW';
 }
-use version; our $VERSION = qv('v0.34.2');
+use version; our $VERSION = qv('v0.34.4');
 		
 use strict;
 use warnings;
@@ -10,11 +10,10 @@ use Type::Utils -all;
 use Type::Library 1.000
 	-base,
 	-declare => qw(
-		FileName					XMLFile						XLSXFile
-		ParserType					Excel_number_0				EpochYear
-		PassThroughType				CellID						PositiveNum
+		XMLFile						XLSXFile					ParserType										
 		NegativeNum					ZeroOrUndef					NotNegativeNum
 		IOFileType					ErrorString					SubString
+		CellID						PositiveNum					Excel_number_0
 	);
 use IO::File;
 BEGIN{ extends "Types::Standard" };
@@ -34,15 +33,6 @@ if( $try_xs and exists $INC{'Type/Tiny/XS.pm'} ){
 
 
 #########1 Type Library       3#########4#########5#########6#########7#########8#########9
-
-declare FileName,
-	as Str,
-    where{ -r $_ },
-    message{ 
-        ( $_ ) ? 
-            "Could not find / read the file: $_" : 
-            'No value passed to the file_name test' 
-    };
 	
 declare XMLFile,
 	as Str,
@@ -88,20 +78,13 @@ coerce IOFileType,
 	from XMLFile,
 	via{  IO::File->new( $_, 'r' ); };
 
-declare ParserType, 
+declare ParserType,
 	as Enum[qw( reader )];#dom  sax
 
 coerce ParserType,
 	from Str,
 	via{ lc( $_ ) };
 
-declare EpochYear,
-	as Int,
-	where{ $_ == 1900 or $_ == 1904 };
-
-declare PassThroughType,
-	as Maybe[Any];
-
 declare CellID,
 	as StrMatch[ qr/^[A-Z]{1,3}[1-9]\d*$/ ];
 	
@@ -176,13 +159,142 @@ Spreadsheet::XLSX::Reader::LibXML::Types - A type library for the LibXML xlsx re
     
 =head1 DESCRIPTION
 
-B<This documentation is written to explain ways to extend this package.  To use the data 
-extraction of Excel workbooks, worksheets, and cells please review the documentation for  
-L<Spreadsheet::XLSX::Reader::LibXML>,
-L<Spreadsheet::XLSX::Reader::LibXML::Worksheet>, and 
-L<Spreadsheet::XLSX::Reader::LibXML::Cell>>
+This documentation is written to explain ways to use this module.  To use the general 
+package for excel parsing out of the box please review the documentation for L<Workbooks
+|Spreadsheet::XLSX::Reader::LibXML>, L<Worksheets
+|Spreadsheet::XLSX::Reader::LibXML::Worksheet>, and 
+L<Cells|Spreadsheet::XLSX::Reader::LibXML::Cell>.
 
-POD not written yet!
+This is a L<Type::Library|Type::Tiny::Manual::Libraries> for this package.  There are no 
+real tricks here outside of the standard Type::Tiny stuf.  For the cool number and date 
+formatting implementation see L<Spreadsheet::XLSX::Reader::LibXML::ParseExcelFormatStrings>.
+
+=head1 TYPES
+
+=head2 XMLFile
+
+This type checks that the value is a readable file (full path - no file find magic 
+used) with an \.xml extention
+
+=head3 coercions
+
+none
+
+=head2 XLSXFile
+
+This type checks that the value is a readable file (full path - no file find magic 
+used)  with an \.xlsx extention
+
+=head3 coercions
+
+none
+
+=head2 IOFileType
+
+This is set as an L<instance of|Types::Standard/InstanceOf[`a]> 'IO::File'
+
+=head3 coercions
+
+=over
+
+B<GlobRef:>  by blessing it into an IO::File instance 'via{  bless $_, 'IO::File' }'
+
+B<XLSXFile:>  by opening it as an IO::File instance 'via{  IO::File->new( $_, 'r' ); }'
+
+B<XMLFile:>  by opening it as an IO::File instance 'via{  IO::File->new( $_, 'r' ); }'
+
+=back
+
+=head2 ParserType
+
+For now this type checks that the parser type string == 'reader'.  As future parser 
+types are added to the package I will update this type.
+
+=head3 coercions
+
+=over
+
+B<Str:> this will lower case any other version of the string 'reader' (Reader| READER) 
+to get it to pass
+
+=back
+
+=head2 PositiveNum
+
+This type checks that the value is a number and is greater than 0
+
+=head3 coercions
+
+none
+
+=head2 NegativeNum
+
+This type checks that the value is a number and is less than 0
+
+=head3 coercions
+
+none
+
+=head2 ZeroOrUndef
+
+This type allows the value to be the number 0 or undef
+
+=head3 coercions
+
+none
+
+=head2 NotNegativeNum
+
+This type checks that the value is a number and that the number is greater than 
+or equal to 0
+
+=head3 coercions
+
+none
+
+=head2 CellID
+
+this is a value that passes the following regular expression test; qr/^[A-Z]{1,3}[1-9]\d*$/
+
+=head3 coercions
+
+none
+
+=head2 SubString
+
+This is a precurser type to ErrorString.  It is used to perform the first layer of coersions 
+so that error objects can be consumed as-is in this package when a subcomponent throws an 
+object rather than a string as an error.
+
+=head3 coercions
+
+=over
+
+B<Object:>  it will test the object for two methods and if either one is present it will use 
+the results of that method as the string.  The methods in order are; 'as_string' and 'message'
+
+=back
+
+=head2 ErrorString
+
+This is a string that can't match the following sequence /\)\n;/ 
+#I don't even remember why that sequence is bad but it is
+
+=head3 coercions
+
+=over
+
+B<SubString:> by using the following substitution on the string; s/\)\n;/\);/g
+
+=back
+
+=head1 NAMED COERCIONS
+
+=head2 Excel_number_0
+
+This is essentially a pass through coercion used as a convenience rather than writing the 
+pass through each time a coercion is needed but no actual work should be performed on the 
+value
 
 =head1 SUPPORT
 
@@ -197,7 +309,7 @@ L<github Spreadsheet::XLSX::Reader::LibXML/issues
 
 =over
 
-B<1.> Add ErrorString type tests to the test suit
+B<1.> The ErrorString type tests still needs a 'fail' case
 
 =back
 
@@ -219,7 +331,7 @@ it and/or modify it under the same terms as Perl itself.
 The full text of the license can be found in the
 LICENSE file included with this module.
 
-This software is copyrighted (c) 2014 by Jed Lund
+This software is copyrighted (c) 2014, 2015 by Jed Lund
 
 =head1 DEPENDENCIES
 
