@@ -21,13 +21,16 @@ use Moose::Util;
 use Spreadsheet::XLSX::Reader::LibXML;
 
 my $parser   = Spreadsheet::XLSX::Reader::LibXML->new();
-my $workbook = $parser->parse( '../../../test_files/TestBook.xlsx' );
+my $workbook = $parser->parse( '../../../test_files/ChartSheet.xlsx' );
 
 if ( !defined $workbook ) {
 	die $parser->error(), "\n";
 }
 
 for my $worksheet ( $workbook->worksheets() ) {
+		
+	#~ # The next line is only necessary if the workbook has chartsheets 
+	#~ next if $worksheet->get_sheet_type ne 'tabular';
 
 	my ( $row_min, $row_max ) = $worksheet->row_range();
 	my ( $col_min, $col_max ) = $worksheet->col_range();
@@ -44,7 +47,7 @@ for my $worksheet ( $workbook->worksheets() ) {
 			print "\n";
 		}
 	}
-	last;# In order not to read all sheets
+	#~ last;# In order not to read all sheets
 }
 
 ###LogSD	package Print::Log;
